# -*- coding: utf-8 -*-
"""
@author: zsc
@time: 2024/11/18
@desc:  存量运营平台-行为客户行为挖掘及监控
"""
import time
import random
from collections import defaultdict
import matplotlib.pyplot as plt

# 主程序

# main.py
from data.collector  import DataCollector
from data.processor  import DataProcessor
from analyze import BehaviorAnalyzer
from analyze import SegmentUsers
from analyze import DetectAnomalies
from monitor import Monitor
from monitor import GenerateReport

# 主函数
def main():
    # 数据收集
    collector = DataCollector.DataCollector()
    raw_data = collector.collect()

    # 数据预处理
    preprocessor = DataProcessor.DataPreprocessor(raw_data)
    processed_data = preprocessor.preprocess()

    # 行为分析
    analyzer = BehaviorAnalyzer.BehaviorAnalyzer(processed_data)
    behavior_data, process_stats, action_stats, product_stats, channel_stats = analyzer.analyze()

    # 用户分群
    segmenter = SegmentUsers.UserSegmentation(behavior_data)
    user_segments = segmenter.segment()

    # 异常检测
    detector = DetectAnomalies.AnomalyDetector(behavior_data)
    anomalies = detector.detect()

    # 报告生成
    generator = GenerateReport.ReportGenerator(processed_data, anomalies, user_segments, process_stats, action_stats, product_stats,
                                channel_stats)
    report = generator.generate()

    # 实时监控
    monitor = Monitor.RealTimeMonitor(processed_data)
    print("\nStarting real-time monitoring...")
    monitor.monitor()



if __name__ == "__main__":
    main()
